@@ -5,5 +5,5 @@ Created on Sat Oct 12 12:43:59 2019
 @author: Edward
 """
 
-
-from . NSFopen import read
+# from . read import read
+# from . process import process
