@@ -184,18 +184,26 @@ class read():
         thermal = {}
         key = 'DataSet-Info'
         if '-- Thermal Tuning --' in header[key]:
-            Q = float(header[key]['Q Factor:'])
+            if 'k' in header[key]['Q Factor:']:
+                Q = float(header[key])['Q Factor:'])*1e3
+            else:
+                Q = float(header[key]['Q Factor:'])
             Freq = header[key]['Frequency:']
             SpringK = header[key]['Spring Constant:']
             Peak = header[key]['Peak Value:']
             
             gr = re.search(r'(\d+\.\d+)(\S*)', Freq).groups()
             Freq = {'Value': gr[0], 'Unit': gr[1]}
-            
-            gr = re.search(r'(\d+\.\d+)\s(\S*)', SpringK).groups()
+            try:
+                gr = re.search(r'(\d+\.\d+)\s(\S*)', SpringK).groups()
+            except:
+               gr = re.search(r'(\d)\s(\S*)', SpringK).groups()
             SpringK = {'Value': gr[0], 'Unit': gr[1]}
             
-            gr = re.search(r'(\d+\.\d+)(\S*)', Peak).groups()
+            try:
+                gr = re.search(r'(\d+\.\d+)(\S*)', Peak).groups()
+            except:
+                gr = re.search(r'(\d)(\S*)', Peak).groups()
             Peak = {'Value': gr[0], 'Unit': gr[1]}
             
             thermal = {'Frequency': Freq, 'Q Factor': Q, 'Spring Constant': SpringK, 'Peak': Peak}
